@@ -11,4 +11,6 @@ export const ControlModeType = {
 export const maxWaypoints = 8;
 
 export const lh2_distance_threshold = 0.01;
+export const lh2_waypoint_area_radius = 0.07;
 export const gps_distance_threshold = 10;  // 10 meters
+export const gps_waypoint_area_radius = 15; // 15 meters
