@@ -5,16 +5,15 @@
 import sys
 import asyncio
 
-from importlib.metadata import version, PackageNotFoundError
-
 import click
 import serial
 
+from dotbot import pydotbot_version
+
 from dotbot.controller import (
     ControllerSettings,
     controller_factory,
     register_controller,
-    DEFAULT_CALIBRATION_DIR,
 )
 from dotbot.keyboard import KeyboardController
 from dotbot.joystick import JoystickController
@@ -82,20 +81,6 @@ DEFAULT_CONTROLLERS = {
     default=False,
     help="Open a web browser automatically",
 )
-@click.option(
-    "-c",
-    "--calibrate",
-    is_flag=True,
-    default=False,
-    help="Run controller in calibration mode (lighthouse mode)",
-)
-@click.option(
-    "-D",
-    "--calibration-dir",
-    type=click.Path(),
-    default=DEFAULT_CALIBRATION_DIR,
-    help="Directory containing calibration files",
-)
 @click.option(
     "-v",
     "--verbose",
@@ -111,17 +96,11 @@ def main(
     gw_address,
     swarm_id,
     webbrowser,
-    calibrate,
-    calibration_dir,
     verbose,
 ):  # pylint: disable=redefined-builtin,too-many-arguments
     """BotController, universal SailBot and DotBot controller."""
     # welcome sentence
-    try:
-        package_version = version("pydotbot")
-    except PackageNotFoundError:
-        package_version = "unknown"
-    print(f"Welcome to the DotBots controller (version: {package_version}).")
+    print(f"Welcome to the DotBots controller (version: {pydotbot_version()}).")
 
     for controller, controller_cls in DEFAULT_CONTROLLERS.items():
         register_controller(controller, controller_cls)
@@ -134,8 +113,6 @@ def main(
                 dotbot_address,
                 gw_address,
                 swarm_id,
-                calibration_dir,
-                calibrate,
                 webbrowser,
                 verbose,
             ),
